var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { Component, Directive, Injectable, Injector, Input, NgModule, Optional, TemplateRef, ViewContainerRef } from '@angular/core';
import { CommonModule } from '@angular/common';
import { ConnectionBackend, Http, HttpModule, RequestOptions, XHRBackend } from '@angular/http';
import { NavigationCancel, NavigationEnd, NavigationError, NavigationStart, Router } from '@angular/router';
import { Subject as Subject$1 } from 'rxjs/Subject';
import 'rxjs/add/operator/finally';
var RouteInterceptorService = (function () {
    /**
     * \@method constructor
     * @param {?} router
     */
    function RouteInterceptorService(router$$1) {
        var _this = this;
        this.router = router$$1;
        this._isPendingRouteSubject = new Subject$1();
        if (this.router) {
            router$$1.events.subscribe(function (event) {
                _this.routerInterceptor(event);
            });
        }
    }
    Object.defineProperty(RouteInterceptorService.prototype, "isPendingRoute", {
        /**
         * [isPendingRoute description]
         * \@method isPendingRoute
         * @return {?}
         */
        get: function () {
            return this._isPendingRouteSubject.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    /**
     * [routerInterceptor description]
     * \@method routerInterceptor
     * @param {?} event
     * @return {?}
     */
    RouteInterceptorService.prototype.routerInterceptor = function (event) {
        if (event instanceof NavigationStart) {
            this.onRouteStart();
        }
        if (event instanceof NavigationEnd || event instanceof NavigationCancel || event instanceof NavigationError) {
            this.onRouteDone();
        }
    };
    /**
     * [onRequestStart description]
     * \@method onRequestStart
     * @return {?}
     */
    RouteInterceptorService.prototype.onRouteStart = function () {
        this._isPendingRouteSubject.next(true);
    };
    /**
     * [onRequestDone description]
     * \@method onRequestDone
     * @return {?}
     */
    RouteInterceptorService.prototype.onRouteDone = function () {
        this._isPendingRouteSubject.next(false);
    };
    return RouteInterceptorService;
}());
RouteInterceptorService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
RouteInterceptorService.ctorParameters = function () { return [
    { type: Router, decorators: [{ type: Optional },] },
]; };
var HttpObservableService = (function () {
    function HttpObservableService() {
        this._pendingRequestsCounter = 0;
        this._isPendingRequestsSubject = new Subject$1();
    }
    Object.defineProperty(HttpObservableService.prototype, "isPendingRequests", {
        /**
         * [isPendingRequests description]
         * \@method isPendingRequests
         * @return {?}
         */
        get: function () {
            return this._isPendingRequestsSubject.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(HttpObservableService.prototype, "pendingRequests", {
        /**
         * [pendingRequests description]
         * \@method pendingRequests
         * @return {?}
         */
        get: function () {
            return this._pendingRequestsCounter;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * [onRequestStart description]
     * \@method onRequestStart
     * @return {?}
     */
    HttpObservableService.prototype.onRequestStart = function () {
        this._pendingRequestsCounter++;
        if (this._pendingRequestsCounter === 1) {
            this._isPendingRequestsSubject.next(true);
        }
    };
    /**
     * [onRequestDone description]
     * \@method onRequestDone
     * @return {?}
     */
    HttpObservableService.prototype.onRequestDone = function () {
        this._pendingRequestsCounter--;
        if (this._pendingRequestsCounter === 0) {
            this._isPendingRequestsSubject.next(false);
        }
    };
    return HttpObservableService;
}());
HttpObservableService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
HttpObservableService.ctorParameters = function () { return []; };
var HttpInterceptorService = (function (_super) {
    __extends(HttpInterceptorService, _super);
    /**
     * \@method constructor
     * @param {?} connectionBackend
     * @param {?} requestOptions
     * @param {?} injector
     */
    function HttpInterceptorService(connectionBackend, requestOptions, injector) {
        var _this = _super.call(this, connectionBackend, requestOptions) || this;
        _this.injector = injector;
        _this.httpObservableService = injector.get(HttpObservableService);
        return _this;
    }
    /**
     * [request description]
     * \@method request
     * @param {?} url
     * @param {?=} options
     * @return {?}
     */
    HttpInterceptorService.prototype.request = function (url, options) {
        var _this = this;
        this.httpObservableService.onRequestStart();
        return _super.prototype.request.call(this, url, options).finally(function () {
            _this.httpObservableService.onRequestDone();
        });
    };
    return HttpInterceptorService;
}(Http));
HttpInterceptorService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
HttpInterceptorService.ctorParameters = function () { return [
    { type: ConnectionBackend, },
    { type: RequestOptions, },
    { type: Injector, },
]; };
/**
 * [httpInterceptorServiceFactory description]
 * \@method httpInterceptorServiceFactory
 * @param {?} xhrBackend
 * @param {?} requestOptions
 * @param {?} injector
 * @return {?}
 */
function httpInterceptorServiceFactory(xhrBackend, requestOptions, injector) {
    return new HttpInterceptorService(xhrBackend, requestOptions, injector);
}
var LoadingPageDirective = (function () {
    /**
     * \@method constructor
     * @param {?} httpObservableService
     * @param {?} routeInterceptorService
     * @param {?} templateRef
     * @param {?} viewContainer
     */
    function LoadingPageDirective(httpObservableService, routeInterceptorService, templateRef, viewContainer) {
        this.httpObservableService = httpObservableService;
        this.routeInterceptorService = routeInterceptorService;
        this.templateRef = templateRef;
        this.viewContainer = viewContainer;
        this.hasView = false;
    }
    /**
     * \@method ngOnChanges
     * @param {?} changes
     * @return {?}
     */
    LoadingPageDirective.prototype.ngOnChanges = function (changes) {
        if (changes.mkLoadingPage.currentValue) {
            this.mkLoadingPage = changes.mkLoadingPage.currentValue;
        }
        if (changes.mkLoadingPage.firstChange) {
            this.init();
        }
    };
    /**
     * [init description]
     * \@method init
     * @return {?}
     */
    LoadingPageDirective.prototype.init = function () {
        var _this = this;
        if (!this.mkLoadingPage || this.mkLoadingPage.checkPendingHttp) {
            this.httpObservableService.isPendingRequests.subscribe(function (value) {
                _this.isPendingRequests = value;
                _this.isVisible();
            });
        }
        if (!this.mkLoadingPage || this.mkLoadingPage.checkPendingRoute) {
            this.routeInterceptorService.isPendingRoute.subscribe(function (value) {
                _this.isPendingRoute = value;
                _this.isVisible();
            });
        }
    };
    /**
     * [isVisible description]
     * \@method isVisible
     * @return {?}
     */
    LoadingPageDirective.prototype.isVisible = function () {
        if (this.hasView && !this.isPendingRequests && !this.isPendingRoute) {
            this.viewContainer.clear();
            this.hasView = false;
        }
        else if (!this.hasView && (this.isPendingRequests || this.isPendingRoute)) {
            this.viewContainer.createEmbeddedView(this.templateRef);
            this.hasView = true;
        }
    };
    return LoadingPageDirective;
}());
LoadingPageDirective.decorators = [
    { type: Directive, args: [{
                selector: '[mkLoadingPage]',
            },] },
];
/**
 * @nocollapse
 */
LoadingPageDirective.ctorParameters = function () { return [
    { type: HttpObservableService, },
    { type: RouteInterceptorService, },
    { type: TemplateRef, },
    { type: ViewContainerRef, },
]; };
LoadingPageDirective.propDecorators = {
    'mkLoadingPage': [{ type: Input },],
};
var LoadingPageModule = (function () {
    function LoadingPageModule() {
    }
    return LoadingPageModule;
}());
LoadingPageModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    HttpModule
                ],
                declarations: [
                    LoadingPageDirective
                ],
                exports: [
                    HttpModule,
                    LoadingPageDirective
                ],
                providers: [
                    RouteInterceptorService,
                    HttpObservableService,
                    { provide: Http,
                        useFactory: httpInterceptorServiceFactory,
                        deps: [XHRBackend, RequestOptions, Injector] }
                ]
            },] },
];
/**
 * @nocollapse
 */
LoadingPageModule.ctorParameters = function () { return []; };
var ChasingDotsComponent = (function () {
    function ChasingDotsComponent() {
        this.colorOne = '#da4733';
        this.colorTwo = '#3b78e7';
    }
    return ChasingDotsComponent;
}());
ChasingDotsComponent.decorators = [
    { type: Component, args: [{
                selector: 'mk-chasing-dots',
                template: "\n    <div class=\"sk-chasing-dots\">\n      <div class=\"sk-child sk-dot1\" [style.background-color]=\"colorOne\"></div>\n      <div class=\"sk-child sk-dot2\" [style.background-color]=\"colorTwo\"></div>\n    </div>",
                styles: ["\n    .sk-chasing-dots {\n      margin: 40px auto;\n      width: 40px;\n      height: 40px;\n      position: relative;\n      text-align: center;\n      -webkit-animation: sk-chasingDotsRotate 2s infinite linear;\n              animation: sk-chasingDotsRotate 2s infinite linear; }\n      .sk-chasing-dots .sk-child {\n        width: 60%;\n        height: 60%;\n        display: inline-block;\n        position: absolute;\n        top: 0;\n        border-radius: 100%;\n        -webkit-animation: sk-chasingDotsBounce 2s infinite ease-in-out;\n                animation: sk-chasingDotsBounce 2s infinite ease-in-out; }\n      .sk-chasing-dots .sk-dot2 {\n        top: auto;\n        bottom: 0;\n        -webkit-animation-delay: -1s;\n                animation-delay: -1s; }\n\n    @-webkit-keyframes sk-chasingDotsRotate {\n      100% {\n        -webkit-transform: rotate(360deg);\n                transform: rotate(360deg); } }\n\n    @keyframes sk-chasingDotsRotate {\n      100% {\n        -webkit-transform: rotate(360deg);\n                transform: rotate(360deg); } }\n\n    @-webkit-keyframes sk-chasingDotsBounce {\n      0%, 100% {\n        -webkit-transform: scale(0);\n                transform: scale(0); }\n      50% {\n        -webkit-transform: scale(1);\n                transform: scale(1); } }\n\n    @keyframes sk-chasingDotsBounce {\n      0%, 100% {\n        -webkit-transform: scale(0);\n                transform: scale(0); }\n      50% {\n        -webkit-transform: scale(1);\n                transform: scale(1); } }\n  "]
            },] },
];
/**
 * @nocollapse
 */
ChasingDotsComponent.ctorParameters = function () { return []; };
ChasingDotsComponent.propDecorators = {
    'colorOne': [{ type: Input },],
    'colorTwo': [{ type: Input },],
};
var ChasingDotsModule = (function () {
    function ChasingDotsModule() {
    }
    return ChasingDotsModule;
}());
ChasingDotsModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    ChasingDotsComponent,
                ],
                exports: [
                    ChasingDotsComponent
                ]
            },] },
];
/**
 * @nocollapse
 */
ChasingDotsModule.ctorParameters = function () { return []; };
var CircleComponent = (function () {
    function CircleComponent() {
        this.color = '#da4733';
    }
    return CircleComponent;
}());
CircleComponent.decorators = [
    { type: Component, args: [{
                selector: 'mk-circle',
                template: "\n    <div class=\"sk-circle\">\n      <div class=\"sk-circle1 sk-child\"><div [style.background-color]=\"color\"></div></div>\n      <div class=\"sk-circle2 sk-child\"><div [style.background-color]=\"color\"></div></div>\n      <div class=\"sk-circle3 sk-child\"><div [style.background-color]=\"color\"></div></div>\n      <div class=\"sk-circle4 sk-child\"><div [style.background-color]=\"color\"></div></div>\n      <div class=\"sk-circle5 sk-child\"><div [style.background-color]=\"color\"></div></div>\n      <div class=\"sk-circle6 sk-child\"><div [style.background-color]=\"color\"></div></div>\n      <div class=\"sk-circle7 sk-child\"><div [style.background-color]=\"color\"></div></div>\n      <div class=\"sk-circle8 sk-child\"><div [style.background-color]=\"color\"></div></div>\n      <div class=\"sk-circle9 sk-child\"><div [style.background-color]=\"color\"></div></div>\n      <div class=\"sk-circle10 sk-child\"><div [style.background-color]=\"color\"></div></div>\n      <div class=\"sk-circle11 sk-child\"><div [style.background-color]=\"color\"></div></div>\n      <div class=\"sk-circle12 sk-child\"><div [style.background-color]=\"color\"></div></div>\n    </div>",
                styles: ["\n    .sk-circle {\n      margin: 40px auto;\n      width: 40px;\n      height: 40px;\n      position: relative; }\n      .sk-circle .sk-child {\n        width: 100%;\n        height: 100%;\n        position: absolute;\n        left: 0;\n        top: 0; }\n      .sk-circle .sk-child > div {\n        display: block;\n        margin: 0 auto;\n        width: 15%;\n        height: 15%;\n        border-radius: 100%;\n        -webkit-animation: sk-circleBounceDelay 1.2s infinite ease-in-out both;\n                animation: sk-circleBounceDelay 1.2s infinite ease-in-out both; }\n      .sk-circle .sk-circle2 {\n        -webkit-transform: rotate(30deg);\n                transform: rotate(30deg); }\n      .sk-circle .sk-circle3 {\n        -webkit-transform: rotate(60deg);\n                transform: rotate(60deg); }\n      .sk-circle .sk-circle4 {\n        -webkit-transform: rotate(90deg);\n                transform: rotate(90deg); }\n      .sk-circle .sk-circle5 {\n        -webkit-transform: rotate(120deg);\n                transform: rotate(120deg); }\n      .sk-circle .sk-circle6 {\n        -webkit-transform: rotate(150deg);\n                transform: rotate(150deg); }\n      .sk-circle .sk-circle7 {\n        -webkit-transform: rotate(180deg);\n                transform: rotate(180deg); }\n      .sk-circle .sk-circle8 {\n        -webkit-transform: rotate(210deg);\n                transform: rotate(210deg); }\n      .sk-circle .sk-circle9 {\n        -webkit-transform: rotate(240deg);\n                transform: rotate(240deg); }\n      .sk-circle .sk-circle10 {\n        -webkit-transform: rotate(270deg);\n                transform: rotate(270deg); }\n      .sk-circle .sk-circle11 {\n        -webkit-transform: rotate(300deg);\n                transform: rotate(300deg); }\n      .sk-circle .sk-circle12 {\n        -webkit-transform: rotate(330deg);\n                transform: rotate(330deg); }\n      .sk-circle .sk-circle2 > div {\n        -webkit-animation-delay: -1.1s;\n                animation-delay: -1.1s; }\n      .sk-circle .sk-circle3 > div {\n        -webkit-animation-delay: -1s;\n                animation-delay: -1s; }\n      .sk-circle .sk-circle4 > div {\n        -webkit-animation-delay: -0.9s;\n                animation-delay: -0.9s; }\n      .sk-circle .sk-circle5 > div {\n        -webkit-animation-delay: -0.8s;\n                animation-delay: -0.8s; }\n      .sk-circle .sk-circle6 > div {\n        -webkit-animation-delay: -0.7s;\n                animation-delay: -0.7s; }\n      .sk-circle .sk-circle7 > div {\n        -webkit-animation-delay: -0.6s;\n                animation-delay: -0.6s; }\n      .sk-circle .sk-circle8 > div {\n        -webkit-animation-delay: -0.5s;\n                animation-delay: -0.5s; }\n      .sk-circle .sk-circle9 > div {\n        -webkit-animation-delay: -0.4s;\n                animation-delay: -0.4s; }\n      .sk-circle .sk-circle10 > div {\n        -webkit-animation-delay: -0.3s;\n                animation-delay: -0.3s; }\n      .sk-circle .sk-circle11 > div {\n        -webkit-animation-delay: -0.2s;\n                animation-delay: -0.2s; }\n      .sk-circle .sk-circle12 > div {\n        -webkit-animation-delay: -0.1s;\n                animation-delay: -0.1s; }\n\n    @-webkit-keyframes sk-circleBounceDelay {\n      0%, 80%, 100% {\n        -webkit-transform: scale(0);\n                transform: scale(0); }\n      40% {\n        -webkit-transform: scale(1);\n                transform: scale(1); } }\n\n    @keyframes sk-circleBounceDelay {\n      0%, 80%, 100% {\n        -webkit-transform: scale(0);\n                transform: scale(0); }\n      40% {\n        -webkit-transform: scale(1);\n                transform: scale(1); } }\n  "]
            },] },
];
/**
 * @nocollapse
 */
CircleComponent.ctorParameters = function () { return []; };
CircleComponent.propDecorators = {
    'color': [{ type: Input },],
};
var CircleModule = (function () {
    function CircleModule() {
    }
    return CircleModule;
}());
CircleModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    CircleComponent,
                ],
                exports: [
                    CircleComponent
                ]
            },] },
];
/**
 * @nocollapse
 */
CircleModule.ctorParameters = function () { return []; };
var CubeGridComponent = (function () {
    function CubeGridComponent() {
        this.color = '#da4733';
    }
    return CubeGridComponent;
}());
CubeGridComponent.decorators = [
    { type: Component, args: [{
                selector: 'mk-cube-grid',
                template: "\n    <div class=\"sk-cube-grid\">\n      <div class=\"sk-cube sk-cube1\" [style.background-color]=\"color\"></div>\n      <div class=\"sk-cube sk-cube2\" [style.background-color]=\"color\"></div>\n      <div class=\"sk-cube sk-cube3\" [style.background-color]=\"color\"></div>\n      <div class=\"sk-cube sk-cube4\" [style.background-color]=\"color\"></div>\n      <div class=\"sk-cube sk-cube5\" [style.background-color]=\"color\"></div>\n      <div class=\"sk-cube sk-cube6\" [style.background-color]=\"color\"></div>\n      <div class=\"sk-cube sk-cube7\" [style.background-color]=\"color\"></div>\n      <div class=\"sk-cube sk-cube8\" [style.background-color]=\"color\"></div>\n      <div class=\"sk-cube sk-cube9\" [style.background-color]=\"color\"></div>\n    </div>",
                styles: ["\n    .sk-cube-grid {\n      width: 40px;\n      height: 40px;\n      margin: 40px auto;\n      /*\n       * Spinner positions\n       * 1 2 3\n       * 4 5 6\n       * 7 8 9\n       */ }\n      .sk-cube-grid .sk-cube {\n        width: 33.33%;\n        height: 33.33%;\n        float: left;\n        -webkit-animation: sk-cubeGridScaleDelay 1.3s infinite ease-in-out;\n                animation: sk-cubeGridScaleDelay 1.3s infinite ease-in-out; }\n      .sk-cube-grid .sk-cube1 {\n        -webkit-animation-delay: 0.2s;\n                animation-delay: 0.2s; }\n      .sk-cube-grid .sk-cube2 {\n        -webkit-animation-delay: 0.3s;\n                animation-delay: 0.3s; }\n      .sk-cube-grid .sk-cube3 {\n        -webkit-animation-delay: 0.4s;\n                animation-delay: 0.4s; }\n      .sk-cube-grid .sk-cube4 {\n        -webkit-animation-delay: 0.1s;\n                animation-delay: 0.1s; }\n      .sk-cube-grid .sk-cube5 {\n        -webkit-animation-delay: 0.2s;\n                animation-delay: 0.2s; }\n      .sk-cube-grid .sk-cube6 {\n        -webkit-animation-delay: 0.3s;\n                animation-delay: 0.3s; }\n      .sk-cube-grid .sk-cube7 {\n        -webkit-animation-delay: 0.0s;\n                animation-delay: 0.0s; }\n      .sk-cube-grid .sk-cube8 {\n        -webkit-animation-delay: 0.1s;\n                animation-delay: 0.1s; }\n      .sk-cube-grid .sk-cube9 {\n        -webkit-animation-delay: 0.2s;\n                animation-delay: 0.2s; }\n\n    @-webkit-keyframes sk-cubeGridScaleDelay {\n      0%, 70%, 100% {\n        -webkit-transform: scale3D(1, 1, 1);\n                transform: scale3D(1, 1, 1); }\n      35% {\n        -webkit-transform: scale3D(0, 0, 1);\n                transform: scale3D(0, 0, 1); } }\n\n    @keyframes sk-cubeGridScaleDelay {\n      0%, 70%, 100% {\n        -webkit-transform: scale3D(1, 1, 1);\n                transform: scale3D(1, 1, 1); }\n      35% {\n        -webkit-transform: scale3D(0, 0, 1);\n                transform: scale3D(0, 0, 1); } }\n  "]
            },] },
];
/**
 * @nocollapse
 */
CubeGridComponent.ctorParameters = function () { return []; };
CubeGridComponent.propDecorators = {
    'color': [{ type: Input },],
};
var CubeGridModule = (function () {
    function CubeGridModule() {
    }
    return CubeGridModule;
}());
CubeGridModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    CubeGridComponent,
                ],
                exports: [
                    CubeGridComponent
                ]
            },] },
];
/**
 * @nocollapse
 */
CubeGridModule.ctorParameters = function () { return []; };
var DoubleBounceComponent = (function () {
    function DoubleBounceComponent() {
        this.colorOne = '#da4733';
        this.colorTwo = '#3b78e7';
    }
    return DoubleBounceComponent;
}());
DoubleBounceComponent.decorators = [
    { type: Component, args: [{
                selector: 'mk-double-bounce',
                template: "\n    <div class=\"sk-double-bounce\">\n      <div class=\"sk-child sk-double-bounce1\" [style.background-color]=\"colorOne\"></div>\n      <div class=\"sk-child sk-double-bounce2\" [style.background-color]=\"colorTwo\"></div>\n    </div>",
                styles: ["\n    .sk-double-bounce {\n      width: 40px;\n      height: 40px;\n      position: relative;\n      margin: 40px auto; }\n      .sk-double-bounce .sk-child {\n        width: 100%;\n        height: 100%;\n        border-radius: 50%;\n        opacity: 0.6;\n        position: absolute;\n        top: 0;\n        left: 0;\n        -webkit-animation: sk-doubleBounce 2s infinite ease-in-out;\n                animation: sk-doubleBounce 2s infinite ease-in-out; }\n      .sk-double-bounce .sk-double-bounce2 {\n        -webkit-animation-delay: -1.0s;\n                animation-delay: -1.0s; }\n\n    @-webkit-keyframes sk-doubleBounce {\n      0%, 100% {\n        -webkit-transform: scale(0);\n                transform: scale(0); }\n      50% {\n        -webkit-transform: scale(1);\n                transform: scale(1); } }\n\n    @keyframes sk-doubleBounce {\n      0%, 100% {\n        -webkit-transform: scale(0);\n                transform: scale(0); }\n      50% {\n        -webkit-transform: scale(1);\n                transform: scale(1); } }\n  "]
            },] },
];
/**
 * @nocollapse
 */
DoubleBounceComponent.ctorParameters = function () { return []; };
DoubleBounceComponent.propDecorators = {
    'colorOne': [{ type: Input },],
    'colorTwo': [{ type: Input },],
};
var DoubleBounceModule = (function () {
    function DoubleBounceModule() {
    }
    return DoubleBounceModule;
}());
DoubleBounceModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    DoubleBounceComponent,
                ],
                exports: [
                    DoubleBounceComponent
                ]
            },] },
];
/**
 * @nocollapse
 */
DoubleBounceModule.ctorParameters = function () { return []; };
var FadingCircleComponent = (function () {
    function FadingCircleComponent() {
        this.color = '#da4733';
    }
    return FadingCircleComponent;
}());
FadingCircleComponent.decorators = [
    { type: Component, args: [{
                selector: 'mk-fading-circle',
                template: "\n    <div class=\"sk-fading-circle\">\n      <div class=\"sk-circle1 sk-circle\"><div [style.background-color]=\"color\"></div></div>\n      <div class=\"sk-circle2 sk-circle\"><div [style.background-color]=\"color\"></div></div>\n      <div class=\"sk-circle3 sk-circle\"><div [style.background-color]=\"color\"></div></div>\n      <div class=\"sk-circle4 sk-circle\"><div [style.background-color]=\"color\"></div></div>\n      <div class=\"sk-circle5 sk-circle\"><div [style.background-color]=\"color\"></div></div>\n      <div class=\"sk-circle6 sk-circle\"><div [style.background-color]=\"color\"></div></div>\n      <div class=\"sk-circle7 sk-circle\"><div [style.background-color]=\"color\"></div></div>\n      <div class=\"sk-circle8 sk-circle\"><div [style.background-color]=\"color\"></div></div>\n      <div class=\"sk-circle9 sk-circle\"><div [style.background-color]=\"color\"></div></div>\n      <div class=\"sk-circle10 sk-circle\"><div [style.background-color]=\"color\"></div></div>\n      <div class=\"sk-circle11 sk-circle\"><div [style.background-color]=\"color\"></div></div>\n      <div class=\"sk-circle12 sk-circle\"><div [style.background-color]=\"color\"></div></div>\n    </div>",
                styles: ["\n    .sk-fading-circle {\n      margin: 40px auto;\n      width: 40px;\n      height: 40px;\n      position: relative; }\n      .sk-fading-circle .sk-circle {\n        width: 100%;\n        height: 100%;\n        position: absolute;\n        left: 0;\n        top: 0; }\n      .sk-fading-circle .sk-circle > div {\n        content: '';\n        display: block;\n        margin: 0 auto;\n        width: 15%;\n        height: 15%;\n        border-radius: 100%;\n        -webkit-animation: sk-circleFadeDelay 1.2s infinite ease-in-out both;\n                animation: sk-circleFadeDelay 1.2s infinite ease-in-out both; }\n      .sk-fading-circle .sk-circle2 {\n        -webkit-transform: rotate(30deg);\n                transform: rotate(30deg); }\n      .sk-fading-circle .sk-circle3 {\n        -webkit-transform: rotate(60deg);\n                transform: rotate(60deg); }\n      .sk-fading-circle .sk-circle4 {\n        -webkit-transform: rotate(90deg);\n                transform: rotate(90deg); }\n      .sk-fading-circle .sk-circle5 {\n        -webkit-transform: rotate(120deg);\n                transform: rotate(120deg); }\n      .sk-fading-circle .sk-circle6 {\n        -webkit-transform: rotate(150deg);\n                transform: rotate(150deg); }\n      .sk-fading-circle .sk-circle7 {\n        -webkit-transform: rotate(180deg);\n                transform: rotate(180deg); }\n      .sk-fading-circle .sk-circle8 {\n        -webkit-transform: rotate(210deg);\n                transform: rotate(210deg); }\n      .sk-fading-circle .sk-circle9 {\n        -webkit-transform: rotate(240deg);\n                transform: rotate(240deg); }\n      .sk-fading-circle .sk-circle10 {\n        -webkit-transform: rotate(270deg);\n                transform: rotate(270deg); }\n      .sk-fading-circle .sk-circle11 {\n        -webkit-transform: rotate(300deg);\n                transform: rotate(300deg); }\n      .sk-fading-circle .sk-circle12 {\n        -webkit-transform: rotate(330deg);\n                transform: rotate(330deg); }\n      .sk-fading-circle .sk-circle2 > div {\n        -webkit-animation-delay: -1.1s;\n                animation-delay: -1.1s; }\n      .sk-fading-circle .sk-circle3 > div {\n        -webkit-animation-delay: -1s;\n                animation-delay: -1s; }\n      .sk-fading-circle .sk-circle4 > div {\n        -webkit-animation-delay: -0.9s;\n                animation-delay: -0.9s; }\n      .sk-fading-circle .sk-circle5 > div {\n        -webkit-animation-delay: -0.8s;\n                animation-delay: -0.8s; }\n      .sk-fading-circle .sk-circle6 > div {\n        -webkit-animation-delay: -0.7s;\n                animation-delay: -0.7s; }\n      .sk-fading-circle .sk-circle7 > div {\n        -webkit-animation-delay: -0.6s;\n                animation-delay: -0.6s; }\n      .sk-fading-circle .sk-circle8 > div {\n        -webkit-animation-delay: -0.5s;\n                animation-delay: -0.5s; }\n      .sk-fading-circle .sk-circle9 > div {\n        -webkit-animation-delay: -0.4s;\n                animation-delay: -0.4s; }\n      .sk-fading-circle .sk-circle10 > div {\n        -webkit-animation-delay: -0.3s;\n                animation-delay: -0.3s; }\n      .sk-fading-circle .sk-circle11 > div {\n        -webkit-animation-delay: -0.2s;\n                animation-delay: -0.2s; }\n      .sk-fading-circle .sk-circle12 > div {\n        -webkit-animation-delay: -0.1s;\n                animation-delay: -0.1s; }\n\n    @-webkit-keyframes sk-circleFadeDelay {\n      0%, 39%, 100% {\n        opacity: 0; }\n      40% {\n        opacity: 1; } }\n\n    @keyframes sk-circleFadeDelay {\n      0%, 39%, 100% {\n        opacity: 0; }\n      40% {\n        opacity: 1; } }\n  "]
            },] },
];
/**
 * @nocollapse
 */
FadingCircleComponent.ctorParameters = function () { return []; };
FadingCircleComponent.propDecorators = {
    'color': [{ type: Input },],
};
var FadingCircleModule = (function () {
    function FadingCircleModule() {
    }
    return FadingCircleModule;
}());
FadingCircleModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    FadingCircleComponent,
                ],
                exports: [
                    FadingCircleComponent
                ]
            },] },
];
/**
 * @nocollapse
 */
FadingCircleModule.ctorParameters = function () { return []; };
var FoldingCubeComponent = (function () {
    function FoldingCubeComponent() {
        this.color = '#da4733';
    }
    return FoldingCubeComponent;
}());
FoldingCubeComponent.decorators = [
    { type: Component, args: [{
                selector: 'mk-folding-cube',
                template: "\n    <div class=\"sk-folding-cube\">\n      <div class=\"sk-cube1 sk-cube\"><div [style.background-color]=\"color\"></div></div>\n      <div class=\"sk-cube2 sk-cube\"><div [style.background-color]=\"color\"></div></div>\n      <div class=\"sk-cube4 sk-cube\"><div [style.background-color]=\"color\"></div></div>\n      <div class=\"sk-cube3 sk-cube\"><div [style.background-color]=\"color\"></div></div>\n    </div>",
                styles: ["\n    .sk-folding-cube {\n      margin: 40px auto;\n      width: 40px;\n      height: 40px;\n      position: relative;\n      -webkit-transform: rotateZ(45deg);\n              transform: rotateZ(45deg); }\n      .sk-folding-cube .sk-cube {\n        float: left;\n        width: 50%;\n        height: 50%;\n        position: relative;\n        -webkit-transform: scale(1.1);\n                transform: scale(1.1); }\n      .sk-folding-cube .sk-cube > div {\n        content: '';\n        position: absolute;\n        top: 0;\n        left: 0;\n        width: 100%;\n        height: 100%;\n        -webkit-animation: sk-foldCubeAngle 2.4s infinite linear both;\n                animation: sk-foldCubeAngle 2.4s infinite linear both;\n        -webkit-transform-origin: 100% 100%;\n                transform-origin: 100% 100%; }\n      .sk-folding-cube .sk-cube2 {\n        -webkit-transform: scale(1.1) rotateZ(90deg);\n                transform: scale(1.1) rotateZ(90deg); }\n      .sk-folding-cube .sk-cube3 {\n        -webkit-transform: scale(1.1) rotateZ(180deg);\n                transform: scale(1.1) rotateZ(180deg); }\n      .sk-folding-cube .sk-cube4 {\n        -webkit-transform: scale(1.1) rotateZ(270deg);\n                transform: scale(1.1) rotateZ(270deg); }\n      .sk-folding-cube .sk-cube2 > div {\n        -webkit-animation-delay: 0.3s;\n                animation-delay: 0.3s; }\n      .sk-folding-cube .sk-cube3 > div {\n        -webkit-animation-delay: 0.6s;\n                animation-delay: 0.6s; }\n      .sk-folding-cube .sk-cube4 > div {\n        -webkit-animation-delay: 0.9s;\n                animation-delay: 0.9s; }\n\n    @-webkit-keyframes sk-foldCubeAngle {\n      0%, 10% {\n        -webkit-transform: perspective(140px) rotateX(-180deg);\n                transform: perspective(140px) rotateX(-180deg);\n        opacity: 0; }\n      25%, 75% {\n        -webkit-transform: perspective(140px) rotateX(0deg);\n                transform: perspective(140px) rotateX(0deg);\n        opacity: 1; }\n      90%, 100% {\n        -webkit-transform: perspective(140px) rotateY(180deg);\n                transform: perspective(140px) rotateY(180deg);\n        opacity: 0; } }\n\n    @keyframes sk-foldCubeAngle {\n      0%, 10% {\n        -webkit-transform: perspective(140px) rotateX(-180deg);\n                transform: perspective(140px) rotateX(-180deg);\n        opacity: 0; }\n      25%, 75% {\n        -webkit-transform: perspective(140px) rotateX(0deg);\n                transform: perspective(140px) rotateX(0deg);\n        opacity: 1; }\n      90%, 100% {\n        -webkit-transform: perspective(140px) rotateY(180deg);\n                transform: perspective(140px) rotateY(180deg);\n        opacity: 0; } }\n  "]
            },] },
];
/**
 * @nocollapse
 */
FoldingCubeComponent.ctorParameters = function () { return []; };
FoldingCubeComponent.propDecorators = {
    'color': [{ type: Input },],
};
var FoldingCubeModule = (function () {
    function FoldingCubeModule() {
    }
    return FoldingCubeModule;
}());
FoldingCubeModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    FoldingCubeComponent,
                ],
                exports: [
                    FoldingCubeComponent
                ]
            },] },
];
/**
 * @nocollapse
 */
FoldingCubeModule.ctorParameters = function () { return []; };
var MaterialbarComponent = (function () {
    function MaterialbarComponent() {
        this.colorOne = '#da4733';
        this.colorTwo = '#3b78e7';
        this.colorThree = '#fdba2c';
    }
    return MaterialbarComponent;
}());
MaterialbarComponent.decorators = [
    { type: Component, args: [{
                selector: 'mk-material-bar',
                template: "\n  <div class=\"material-bar\">\n    <div class=\"bar\" [style.background-color]=\"colorOne\"></div>\n    <div class=\"bar\" [style.background-color]=\"colorTwo\"></div>\n    <div class=\"bar\" [style.background-color]=\"colorThree\"></div>\n  </div>",
                styles: ["\n    .material-bar {\n      position: relative;\n      width: 100%;\n      height: 4px;\n      background-color: #fdba2c;\n    }\n    .bar {\n      content: \"\";\n      display: inline;\n      position: absolute;\n      width: 0;\n      height: 100%;\n      left: 50%;\n      text-align: center;\n    }\n    .bar:nth-child(1) {\n      -webkit-animation: loading 3s linear infinite;\n              animation: loading 3s linear infinite;\n    }\n    .bar:nth-child(2) {\n      -webkit-animation: loading 3s linear 1s infinite;\n              animation: loading 3s linear 1s infinite;\n    }\n    .bar:nth-child(3) {\n      -webkit-animation: loading 3s linear 2s infinite;\n              animation: loading 3s linear 2s infinite;\n    }\n    @-webkit-keyframes loading {\n        from {left: 50%; width: 0;z-index:100;}\n        33.3333% {left: 0; width: 100%;z-index: 10;}\n        to {left: 0; width: 100%;}\n    }\n    @keyframes loading {\n        from {left: 50%; width: 0;z-index:100;}\n        33.3333% {left: 0; width: 100%;z-index: 10;}\n        to {left: 0; width: 100%;}\n    }\n  "]
            },] },
];
/**
 * @nocollapse
 */
MaterialbarComponent.ctorParameters = function () { return []; };
MaterialbarComponent.propDecorators = {
    'colorOne': [{ type: Input },],
    'colorTwo': [{ type: Input },],
    'colorThree': [{ type: Input },],
};
var MaterialBarModule = (function () {
    function MaterialBarModule() {
    }
    return MaterialBarModule;
}());
MaterialBarModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    MaterialbarComponent,
                ],
                exports: [
                    MaterialbarComponent
                ]
            },] },
];
/**
 * @nocollapse
 */
MaterialBarModule.ctorParameters = function () { return []; };
var PulseComponent = (function () {
    function PulseComponent() {
        this.color = '#da4733';
    }
    return PulseComponent;
}());
PulseComponent.decorators = [
    { type: Component, args: [{
                selector: 'mk-pulse',
                template: "<div class=\"sk-spinner sk-spinner-pulse\" [style.background-color]=\"color\"></div>",
                styles: ["\n    .sk-spinner-pulse {\n      width: 40px;\n      height: 40px;\n      margin: 40px auto;\n      background-color: #333;\n      border-radius: 100%;\n      -webkit-animation: sk-pulseScaleOut 1s infinite ease-in-out;\n              animation: sk-pulseScaleOut 1s infinite ease-in-out; }\n\n    @-webkit-keyframes sk-pulseScaleOut {\n      0% {\n        -webkit-transform: scale(0);\n                transform: scale(0); }\n      100% {\n        -webkit-transform: scale(1);\n                transform: scale(1);\n        opacity: 0; } }\n\n    @keyframes sk-pulseScaleOut {\n      0% {\n        -webkit-transform: scale(0);\n                transform: scale(0); }\n      100% {\n        -webkit-transform: scale(1);\n                transform: scale(1);\n        opacity: 0; } }\n  "]
            },] },
];
/**
 * @nocollapse
 */
PulseComponent.ctorParameters = function () { return []; };
PulseComponent.propDecorators = {
    'color': [{ type: Input },],
};
var PulseModule = (function () {
    function PulseModule() {
    }
    return PulseModule;
}());
PulseModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    PulseComponent,
                ],
                exports: [
                    PulseComponent
                ]
            },] },
];
/**
 * @nocollapse
 */
PulseModule.ctorParameters = function () { return []; };
var SlidingBarComponent = (function () {
    function SlidingBarComponent() {
        this.colorOne = '#ddd';
        this.colorTwo = '#3c8dbc';
    }
    return SlidingBarComponent;
}());
SlidingBarComponent.decorators = [
    { type: Component, args: [{
                selector: 'mk-sliding-bar',
                template: "<div class=\"sliding-bar\" [style.background-color]=\"colorOne\"><div [style.background-color]=\"colorTwo\"></div></div>",
                styles: ["\n    .sliding-bar {\n      height: 4px;\n      width: 100%;\n      position: relative;\n      overflow: hidden;\n    }\n    .sliding-bar > div {\n      display: block;\n      position: absolute;\n      content: \"\";\n      left: -200px;\n      width: 200px;\n      height: 4px;\n      background-color: #2980b9;\n      -webkit-animation: loading 2s linear infinite;\n              animation: loading 2s linear infinite;\n    }\n\n    @-webkit-keyframes loading {\n        from {left: -200px; width: 30%;}\n        50% {width: 30%;}\n        70% {width: 70%;}\n        80% { left: 50%;}\n        95% {left: 120%;}\n        to {left: 100%;}\n    }\n\n    @keyframes loading {\n        from {left: -200px; width: 30%;}\n        50% {width: 30%;}\n        70% {width: 70%;}\n        80% { left: 50%;}\n        95% {left: 120%;}\n        to {left: 100%;}\n    }\n  "]
            },] },
];
/**
 * @nocollapse
 */
SlidingBarComponent.ctorParameters = function () { return []; };
SlidingBarComponent.propDecorators = {
    'colorOne': [{ type: Input },],
    'colorTwo': [{ type: Input },],
};
var SlidingBarModule = (function () {
    function SlidingBarModule() {
    }
    return SlidingBarModule;
}());
SlidingBarModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    SlidingBarComponent,
                ],
                exports: [
                    SlidingBarComponent
                ]
            },] },
];
/**
 * @nocollapse
 */
SlidingBarModule.ctorParameters = function () { return []; };
var ThreeBounceComponent = (function () {
    function ThreeBounceComponent() {
        this.colorOne = '#00a65a';
        this.colorTwo = '#fdba2c';
        this.colorThree = '#da4733';
    }
    return ThreeBounceComponent;
}());
ThreeBounceComponent.decorators = [
    { type: Component, args: [{
                selector: 'mk-three-bounce',
                template: "\n    <div class=\"sk-three-bounce\">\n       <div class=\"sk-child sk-bounce1\" [style.background-color]=\"colorOne\"></div>\n       <div class=\"sk-child sk-bounce2\" [style.background-color]=\"colorTwo\"></div>\n       <div class=\"sk-child sk-bounce3\" [style.background-color]=\"colorThree\"></div>\n     </div>",
                styles: ["\n    .sk-three-bounce {\n      margin: 40px auto;\n      width: 80px;\n      text-align: center; }\n      .sk-three-bounce .sk-child {\n        width: 20px;\n        height: 20px;\n        background-color: #333;\n        border-radius: 100%;\n        display: inline-block;\n        -webkit-animation: sk-three-bounce 1.4s ease-in-out 0s infinite both;\n                animation: sk-three-bounce 1.4s ease-in-out 0s infinite both; }\n      .sk-three-bounce .sk-bounce1 {\n        -webkit-animation-delay: -0.32s;\n                animation-delay: -0.32s; }\n      .sk-three-bounce .sk-bounce2 {\n        -webkit-animation-delay: -0.16s;\n                animation-delay: -0.16s; }\n\n    @-webkit-keyframes sk-three-bounce {\n      0%, 80%, 100% {\n        -webkit-transform: scale(0);\n                transform: scale(0); }\n      40% {\n        -webkit-transform: scale(1);\n                transform: scale(1); } }\n\n    @keyframes sk-three-bounce {\n      0%, 80%, 100% {\n        -webkit-transform: scale(0);\n                transform: scale(0); }\n      40% {\n        -webkit-transform: scale(1);\n                transform: scale(1); } }\n  "]
            },] },
];
/**
 * @nocollapse
 */
ThreeBounceComponent.ctorParameters = function () { return []; };
ThreeBounceComponent.propDecorators = {
    'colorOne': [{ type: Input },],
    'colorTwo': [{ type: Input },],
    'colorThree': [{ type: Input },],
};
var ThreeBounceModule = (function () {
    function ThreeBounceModule() {
    }
    return ThreeBounceModule;
}());
ThreeBounceModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    ThreeBounceComponent,
                ],
                exports: [
                    ThreeBounceComponent
                ]
            },] },
];
/**
 * @nocollapse
 */
ThreeBounceModule.ctorParameters = function () { return []; };
var WanderingCubesComponent = (function () {
    function WanderingCubesComponent() {
        this.colorOne = '#da4733';
        this.colorTwo = '#3b78e7';
    }
    return WanderingCubesComponent;
}());
WanderingCubesComponent.decorators = [
    { type: Component, args: [{
                selector: 'mk-wandering-cubes',
                template: "\n    <div class=\"sk-wandering-cubes\">\n      <div class=\"sk-cube sk-cube1\" [style.background-color]=\"colorOne\"></div>\n      <div class=\"sk-cube sk-cube2\" [style.background-color]=\"colorTwo\"></div>\n    </div>",
                styles: ["\n    .sk-wandering-cubes {\n      margin: 40px auto;\n      width: 40px;\n      height: 40px;\n      position: relative; }\n      .sk-wandering-cubes .sk-cube {\n        width: 10px;\n        height: 10px;\n        position: absolute;\n        top: 0;\n        left: 0;\n        -webkit-animation: sk-wanderingCube 1.8s ease-in-out -1.8s infinite both;\n                animation: sk-wanderingCube 1.8s ease-in-out -1.8s infinite both; }\n      .sk-wandering-cubes .sk-cube2 {\n        -webkit-animation-delay: -0.9s;\n                animation-delay: -0.9s; }\n\n    @-webkit-keyframes sk-wanderingCube {\n      0% {\n        -webkit-transform: rotate(0deg);\n                transform: rotate(0deg); }\n      25% {\n        -webkit-transform: translateX(30px) rotate(-90deg) scale(0.5);\n                transform: translateX(30px) rotate(-90deg) scale(0.5); }\n      50% {\n        /* Hack to make FF rotate in the right direction */\n        -webkit-transform: translateX(30px) translateY(30px) rotate(-179deg);\n                transform: translateX(30px) translateY(30px) rotate(-179deg); }\n      50.1% {\n        -webkit-transform: translateX(30px) translateY(30px) rotate(-180deg);\n                transform: translateX(30px) translateY(30px) rotate(-180deg); }\n      75% {\n        -webkit-transform: translateX(0) translateY(30px) rotate(-270deg) scale(0.5);\n                transform: translateX(0) translateY(30px) rotate(-270deg) scale(0.5); }\n      100% {\n        -webkit-transform: rotate(-360deg);\n                transform: rotate(-360deg); } }\n\n    @keyframes sk-wanderingCube {\n      0% {\n        -webkit-transform: rotate(0deg);\n                transform: rotate(0deg); }\n      25% {\n        -webkit-transform: translateX(30px) rotate(-90deg) scale(0.5);\n                transform: translateX(30px) rotate(-90deg) scale(0.5); }\n      50% {\n        /* Hack to make FF rotate in the right direction */\n        -webkit-transform: translateX(30px) translateY(30px) rotate(-179deg);\n                transform: translateX(30px) translateY(30px) rotate(-179deg); }\n      50.1% {\n        -webkit-transform: translateX(30px) translateY(30px) rotate(-180deg);\n                transform: translateX(30px) translateY(30px) rotate(-180deg); }\n      75% {\n        -webkit-transform: translateX(0) translateY(30px) rotate(-270deg) scale(0.5);\n                transform: translateX(0) translateY(30px) rotate(-270deg) scale(0.5); }\n      100% {\n        -webkit-transform: rotate(-360deg);\n                transform: rotate(-360deg); } }\n  "]
            },] },
];
/**
 * @nocollapse
 */
WanderingCubesComponent.ctorParameters = function () { return []; };
WanderingCubesComponent.propDecorators = {
    'colorOne': [{ type: Input },],
    'colorTwo': [{ type: Input },],
};
var WanderingCubesModule = (function () {
    function WanderingCubesModule() {
    }
    return WanderingCubesModule;
}());
WanderingCubesModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    WanderingCubesComponent,
                ],
                exports: [
                    WanderingCubesComponent
                ]
            },] },
];
/**
 * @nocollapse
 */
WanderingCubesModule.ctorParameters = function () { return []; };
var WaveComponent = (function () {
    function WaveComponent() {
        this.color = '#da4733';
    }
    return WaveComponent;
}());
WaveComponent.decorators = [
    { type: Component, args: [{
                selector: 'mk-wave',
                template: "\n    <div class=\"sk-wave\">\n      <div class=\"sk-rect sk-rect1\" [style.background-color]=\"color\"></div>\n      <div class=\"sk-rect sk-rect2\" [style.background-color]=\"color\"></div>\n      <div class=\"sk-rect sk-rect3\" [style.background-color]=\"color\"></div>\n      <div class=\"sk-rect sk-rect4\" [style.background-color]=\"color\"></div>\n      <div class=\"sk-rect sk-rect5\" [style.background-color]=\"color\"></div>\n    </div>",
                styles: ["\n    .sk-wave {\n      margin: 40px auto;\n      width: 50px;\n      height: 40px;\n      text-align: center;\n      font-size: 10px; }\n      .sk-wave .sk-rect {\n        height: 100%;\n        width: 6px;\n        display: inline-block;\n        -webkit-animation: sk-waveStretchDelay 1.2s infinite ease-in-out;\n                animation: sk-waveStretchDelay 1.2s infinite ease-in-out; }\n      .sk-wave .sk-rect1 {\n        -webkit-animation-delay: -1.2s;\n                animation-delay: -1.2s; }\n      .sk-wave .sk-rect2 {\n        -webkit-animation-delay: -1.1s;\n                animation-delay: -1.1s; }\n      .sk-wave .sk-rect3 {\n        -webkit-animation-delay: -1s;\n                animation-delay: -1s; }\n      .sk-wave .sk-rect4 {\n        -webkit-animation-delay: -0.9s;\n                animation-delay: -0.9s; }\n      .sk-wave .sk-rect5 {\n        -webkit-animation-delay: -0.8s;\n                animation-delay: -0.8s; }\n\n    @-webkit-keyframes sk-waveStretchDelay {\n      0%, 40%, 100% {\n        -webkit-transform: scaleY(0.4);\n                transform: scaleY(0.4); }\n      20% {\n        -webkit-transform: scaleY(1);\n                transform: scaleY(1); } }\n\n    @keyframes sk-waveStretchDelay {\n      0%, 40%, 100% {\n        -webkit-transform: scaleY(0.4);\n                transform: scaleY(0.4); }\n      20% {\n        -webkit-transform: scaleY(1);\n                transform: scaleY(1); } }\n  "]
            },] },
];
/**
 * @nocollapse
 */
WaveComponent.ctorParameters = function () { return []; };
WaveComponent.propDecorators = {
    'color': [{ type: Input },],
};
var WaveModule = (function () {
    function WaveModule() {
    }
    return WaveModule;
}());
WaveModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    WaveComponent,
                ],
                exports: [
                    WaveComponent
                ]
            },] },
];
/**
 * @nocollapse
 */
WaveModule.ctorParameters = function () { return []; };
/**
 * Generated bundle index. Do not edit.
 */
export { LoadingPageModule, LoadingPageDirective, HttpInterceptorService, httpInterceptorServiceFactory, HttpObservableService, RouteInterceptorService, ChasingDotsModule, ChasingDotsComponent, CircleModule, CircleComponent, CubeGridModule, CubeGridComponent, DoubleBounceModule, DoubleBounceComponent, FadingCircleModule, FadingCircleComponent, FoldingCubeModule, FoldingCubeComponent, MaterialBarModule, MaterialbarComponent, PulseModule, PulseComponent, SlidingBarModule, SlidingBarComponent, ThreeBounceModule, ThreeBounceComponent, WanderingCubesModule, WanderingCubesComponent, WaveModule, WaveComponent };
//# sourceMappingURL=angular-loading-page.es5.js.map
